==> gbsite-1.1.0.tar.gz: gbsite/include/mktg_survey.php <==
<?
    /*
     * File: mktg_survey.php
     *
     * Description: This file outputs the html for the marketing survey
     *              mailing list form. This may not be the best place to
     *              put this file but it makes it the most accessible at
     *              this time as there will be more than one file that
     *              uses it in the future.
     *
     *              There are two variable you can define before including
     *              this file and those are $mktg_code and $send_to.
     *              - $mktg_code will be the code that is passed along and
     *                placed on the record that stores the info.
     *              - $send_to will be a page that the user is sent to once
     *                the survey has been filled out. If this is blank then
     *                the user is sent to the context page with a thank you
     *                message.
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 11/15/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 11/15/2000
     *         - Initial file creation
     *     Chris Ryan <chris@Greatbridge.com> 11/20/2000
     *         - Added call to getStates() function
     *         - Changed the state field to a drop down box
     */

    $stateList = getStates();
 ?>
            <form action="/info/ml.php"  method="post">
            <input type="hidden" name="mktg_code" value="<?= $mktg_code ?>">
            <input type="hidden" name="send_to" value="<?= $send_to ?>">
            <table cellpadding="0" cellspacing="5" border="0" width="453">
              <tr>
                <td width="207" rowspan="2" valign="top">

<font face="<?= $font_1 ?>" size="2" color="#000000">
First Name:</font>

<font face="<?= $font_1 ?>" size="1" color="#F1141A">(required)</font><br><input type="text" name="first_name" value="<?= $first_name ?>" size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">Last Name:</font>

<font face="<?= $font_1 ?>" size="1" color="#F1141A">(required)</font><br><input type="text" name="last_name" value="<?= $last_name ?>"size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">Email:</font>

<font face="<?= $font_1 ?>" size="1" color="#F1141A">(required)</font><br><input type="text" name="email" value="<?= $email ?>"size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Company:</font><br><input type="text" name="company" value="<?= $company ?>"size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Address:</font><br><input type="text" name="address" value="<?= $address ?>"size="30"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
City:</font><br><input type="text" name="city" value="<?= $city ?>"size="30"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
State:</font><br><select name="state">
                 <option value="">-- Select a State --</option>
<? while(list($state_code,$state) = @each($stateList)) { ?>
                 <option value="<?= $state_code ?>"><?= $state["name"] ?></option>
<? } ?>
                 </select><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
ZIP:</font><br><input type="text" name="zip" value="<?= $zip ?>"size="10"><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">What OS do you operate?<br>&nbsp;&nbsp;<SELECT NAME="operating_system" SIZE="6" MULTIPLE="yes">
<OPTION>Linux
<OPTION>Solaris
<OPTION>xBSD
<OPTION>AIX
<OPTION>Windows NT/2000
<OPTION>Other
</SELECT><br><font sizes="1">You may select more than one (Windows users, hold down Ctrl key).</font></font><p>



<font face="<?= $font_1 ?>" size="2" color="#000000">What is your job function? <SELECT NAME="job_function" SIZE="1">
<OPTION SELECTED value="">- Select One -
<OPTION>Corporate Management
<OPTION>MIS Management
<OPTION>Network Management
<OPTION>Marketing/Sales
<OPTION>Financial Management
<OPTION>Technical/Engineering Management
<OPTION>Programming/Database Developer
<OPTION>Graphics/Design
<OPTION>Other
</SELECT></font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">What is your organization's primary activity? <SELECT NAME="activity" SIZE="1">
<OPTION SELECTED value="">- Select One -
<OPTION>Web/Internet Development
<OPTION>Computer/Products Manufacturer
<OPTION>VAR/VAD System Integrator
<OPTION>Computer/Business Services
<OPTION>Non-Computer Products Manufacturer
<OPTION>Computer Products Dealer/Distributor
<OPTION>Agriculture/Mining/Construction
<OPTION>Finance/Insurance/Real Estate
<OPTION>Public Utility/Transportation/Media
<OPTION>Government
<OPTION>Medicine/Law
<OPTION>Wholesale/Retail/Trade
<OPTION>Education
<OPTION>Health Services
<OPTION>Other
</SELECT></font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">What is the employee size of your organization? <SELECT NAME="size" SIZE="1">
<OPTION SELECTED value="">- Select One -
<OPTION>1-100
<OPTION>101-500
<OPTION>501-1,000
<OPTION>1,001-5,000
<OPTION>5,000+
</SELECT></font><p>



</td><p>


<td><img src="<?= $image_path ?>/shim.gif" width=20 height=1 alt="" border="0"></td>
<td width="216" valign="top">

<font face="<?= $font_1 ?>" size="2" color="#000000">Are you currently using PostgreSQL ?<br>
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<INPUT TYPE="radio" NAME="postgres_user" VALUE="true">Yes
<INPUT TYPE="radio" NAME="postgres_user" VALUE="false">No</font><p>


<font face="<?= $font_1 ?>" size="2" color="#000000">Would you like to receive our monthly email newsletter (text only)?<br>
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<INPUT TYPE="radio" NAME="newsletter" VALUE="true">Yes
<INPUT TYPE="radio" NAME="newsletter" VALUE="false">No</font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">Would you like us to mail new versions of PostgreSQL to you on CD?</font><br>
<font face="<?= $font_1 ?>" size="1" color="#000000">(If yes, don't forget to give us your mailing address on the left.)</font>
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<font face="<?= $font_1 ?>" size="2" color="#000000">
<INPUT TYPE="radio" NAME="mail_CD" VALUE="true">Yes
<INPUT TYPE="radio" NAME="mail_CD" VALUE="false">No</font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Would you like us to contact you about Great Bridge products and services?
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<INPUT TYPE="radio" NAME="contact_me" VALUE="true">Yes
<INPUT TYPE="radio" NAME="contact_me" VALUE="false">No</font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Comments:</font><br><TEXTAREA NAME="comment" ROWS="10" COLS="30"></TEXTAREA> <p>


</td>
              </tr>
            </table>
<center><input type="submit" name="submit" value="Click To Submit"></center>
            </form>

==> gbsite-2.0.0.tar.gz: gbsite/include/mktg_survey.php <==
<?
    /*
     * File: mktg_survey.php
     *
     * Description: This file outputs the html for the marketing survey
     *              mailing list form. This may not be the best place to
     *              put this file but it makes it the most accessible at
     *              this time as there will be more than one file that
     *              uses it in the future.
     *
     *              There are two variable you can define before including
     *              this file and those are $mktg_code and $send_to.
     *              - $mktg_code will be the code that is passed along and
     *                placed on the record that stores the info.
     *              - $send_to will be a page that the user is sent to once
     *                the survey has been filled out. If this is blank then
     *                the user is sent to the context page with a thank you
     *                message.
     *
     * Creator: Chris Ryan <chris@greatbridge.com>
     * Created: 11/15/2000
     *
     * Change Log:
     *     Chris Ryan <chris@greatbridge.com> 11/15/2000
     *         - Initial file creation
     *     Chris Ryan <chris@Greatbridge.com> 11/20/2000
     *         - Added call to getStates() function
     *         - Changed the state field to a drop down box
     */

    $stateList = getStates();
    $cntryList = getCountries();
 ?>
            <form action="/info/ml.php"  method="post">
            <input type="hidden" name="mktg_code" value="<?= $mktg_code ?>">
            <input type="hidden" name="send_to" value="<?= $send_to ?>">
            <table cellpadding="0" cellspacing="5" border="0" width="453">
              <tr>
                <td width="207" rowspan="2" valign="top">

<font face="<?= $font_1 ?>" size="2" color="#000000">
First Name:</font>

<font face="<?= $font_1 ?>" size="1" color="#F1141A">(required)</font><br><input type="text" name="first_name" value="<?= $first_name ?>" size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">Last Name:</font>

<font face="<?= $font_1 ?>" size="1" color="#F1141A">(required)</font><br><input type="text" name="last_name" value="<?= $last_name ?>"size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">Email:</font>

<font face="<?= $font_1 ?>" size="1" color="#F1141A">(required)</font><br><input type="text" name="email" value="<?= $email ?>"size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Company:</font><br><input type="text" name="company" value="<?= $company ?>"size="20"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Address:</font><br><input type="text" name="address" value="<?= $address ?>"size="30"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
City:</font><br><input type="text" name="city" value="<?= $city ?>"size="30"><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
State:</font><br><select name="state">
                 <option value="">-- Select a State --</option>
<? while(list($state_code,$state) = @each($stateList)) { ?>
                 <option value="<?= $state_code ?>"><?= $state["name"] ?></option>
<? } ?>
                 </select><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Country:</font><br><select name="country">
                 <option value="">-- Select a Country --</option>
<? while(list($co_code,$cntry) = @each($cntryList)) { ?>
                 <option value="<?= $co_code ?>"><?= $cntry ?></option>
<? } ?>
                 </select><br>

<font face="<?= $font_1 ?>" size="2" color="#000000">
ZIP:</font><br><input type="text" name="zip" value="<?= $zip ?>"size="10"><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">What OS do you operate?<br>&nbsp;&nbsp;<SELECT NAME="operating_system" SIZE="6" MULTIPLE="yes">
<OPTION>Linux
<OPTION>Solaris
<OPTION>xBSD
<OPTION>AIX
<OPTION>Windows NT/2000
<OPTION>Other
</SELECT><br><font sizes="1">You may select more than one (Windows users, hold down Ctrl key).</font></font><p>



<font face="<?= $font_1 ?>" size="2" color="#000000">What is your job function? <SELECT NAME="job_function" SIZE="1">
<OPTION SELECTED value="">- Select One -
<OPTION>Corporate Management
<OPTION>MIS Management
<OPTION>Network Management
<OPTION>Marketing/Sales
<OPTION>Financial Management
<OPTION>Technical/Engineering Management
<OPTION>Programming/Database Developer
<OPTION>Graphics/Design
<OPTION>Other
</SELECT></font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">What is your organization's primary activity? <SELECT NAME="activity" SIZE="1">
<OPTION SELECTED value="">- Select One -
<OPTION>Web/Internet Development
<OPTION>Computer/Products Manufacturer
<OPTION>VAR/VAD System Integrator
<OPTION>Computer/Business Services
<OPTION>Non-Computer Products Manufacturer
<OPTION>Computer Products Dealer/Distributor
<OPTION>Agriculture/Mining/Construction
<OPTION>Finance/Insurance/Real Estate
<OPTION>Public Utility/Transportation/Media
<OPTION>Government
<OPTION>Medicine/Law
<OPTION>Wholesale/Retail/Trade
<OPTION>Education
<OPTION>Health Services
<OPTION>Other
</SELECT></font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">What is the employee size of your organization? <SELECT NAME="size" SIZE="1">
<OPTION SELECTED value="">- Select One -
<OPTION>1-100
<OPTION>101-500
<OPTION>501-1,000
<OPTION>1,001-5,000
<OPTION>5,000+
</SELECT></font><p>



</td><p>


<td><img src="<?= $image_path ?>/shim.gif" width=20 height=1 alt="" border="0"></td>
<td width="216" valign="top">

<font face="<?= $font_1 ?>" size="2" color="#000000">Are you currently using PostgreSQL ?<br>
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<INPUT TYPE="radio" NAME="postgres_user" VALUE="true">Yes
<INPUT TYPE="radio" NAME="postgres_user" VALUE="false">No</font><p>


<font face="<?= $font_1 ?>" size="2" color="#000000">Would you like to receive our monthly email newsletter (text only)?<br>
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<INPUT TYPE="radio" NAME="newsletter" VALUE="true">Yes
<INPUT TYPE="radio" NAME="newsletter" VALUE="false">No</font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">Would you like us to mail new versions of PostgreSQL to you on CD?</font><br>
<font face="<?= $font_1 ?>" size="1" color="#000000">(If yes, don't forget to give us your mailing address on the left.)</font>
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<font face="<?= $font_1 ?>" size="2" color="#000000">
<INPUT TYPE="radio" NAME="mail_CD" VALUE="true">Yes
<INPUT TYPE="radio" NAME="mail_CD" VALUE="false">No</font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Would you like us to contact you about Great Bridge products and services?
<img src="<?= $image_path ?>/shim.gif" width=4 height=5 alt="" border="0"><br>
<INPUT TYPE="radio" NAME="contact_me" VALUE="true">Yes
<INPUT TYPE="radio" NAME="contact_me" VALUE="false">No</font><p>

<font face="<?= $font_1 ?>" size="2" color="#000000">
Comments:</font><br><TEXTAREA NAME="comment" ROWS="10" COLS="30" wrap="virtual"></TEXTAREA> <p>


</td>
              </tr>
            </table>
<center><input type="submit" name="submit" value="Click To Submit"></center>
            </form>
